==> haskell-kvitable-1.0.3.0-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kvitable
version:              1.0.3.0
visibility:           public
id:                   kvitable-1.0.3.0-BNSpHI1yAeA6tuZ7FV8TCf
key:                  kvitable-1.0.3.0-BNSpHI1yAeA6tuZ7FV8TCf
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  30cee254c2e13262709e0919ad8578d8
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Render Data.KVITable.Render.ASCII
    Data.KVITable.Render.HTML

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.0.3.0-BNSpHI1yAeA6tuZ7FV8TCf
depends:
    base-4.17.2.1 containers-0.6.7
    lucid-2.11.20230408-3x03UWC2tK0AASxsCveu1L
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    prettyprinter-1.7.1-KavgWlSYS7L7YXURHbWfqH text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kvitable-1.0.3.0-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kvitable
version:              1.0.3.0
visibility:           public
id:                   kvitable-1.0.3.0-4QGf0nTbSqfAbIM66Ty3gN
key:                  kvitable-1.0.3.0-4QGf0nTbSqfAbIM66Ty3gN
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  331e8782567676c6390d317ae74152c9
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Render Data.KVITable.Render.ASCII
    Data.KVITable.Render.HTML

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.0.3.0-4QGf0nTbSqfAbIM66Ty3gN
depends:
    base-4.17.2.1 containers-0.6.7
    lucid-2.11.20230408-GLFkKjpgSzVJ4HG9upn5Wv
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    prettyprinter-1.7.1-KbA7i78IS3P9O3YxKJ8q7i text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
